@@ -6,11 +6,18 @@ library(BioInstaller)
 set.biosoftwares.db(tempfile())
 # Show all avaliable softwares/dependece in default inst/extdata/config/github/github.toml 
 # and inst/extdata/config/nongithub/nongithub.toml
-install.bioinfo(show.all.names = TRUE)
+x <- install.bioinfo(show.all.names = TRUE)
 
+## ----echo = FALSE--------------------------------------------------------
+suppressWarnings(
+  DT::datatable(matrix(x, ncol=3), caption = sprintf("Items supported by BioInstaller"))
+)
+
+## ------------------------------------------------------------------------
 # Fetching versions of softwares
-install.bioinfo('samtools', show.all.versions = TRUE)
+install.bioinfo(name = 'samtools', show.all.versions = TRUE)
 
+## ------------------------------------------------------------------------
 # Install 'demo' with debug infomation
 download.dir <- sprintf('%s/demo_2', tempdir())
 install.bioinfo('demo', download.dir = download.dir, verbose = TRUE)
@@ -20,6 +27,7 @@ download.dir <- sprintf('%s/demo_3', tempdir())
 install.bioinfo('demo', download.dir = download.dir,
   download.only = TRUE, verbose = TRUE)
 
+## ------------------------------------------------------------------------
 # Set download.dir and destdir (destdir like /usr/local 
 # including bin, lib, include and others), 
 # destdir will work if install step {{destdir}} be used
@@ -35,6 +43,8 @@ is.biosoftwares.db.active(temp.db)
 # Install 'demo' quite
 download.dir <- sprintf('%s/demo_1', tempdir())
 install.bioinfo('demo', download.dir = download.dir, verbose = FALSE)
+
+## ------------------------------------------------------------------------
 config <- get.info('demo')
 config
 
@@ -47,16 +57,19 @@ del.info('demo')
 
 ## ------------------------------------------------------------------------
 download.dir <- sprintf('%s/github_demo_local', tempdir())
+tryCatch({
 install.bioinfo('github_demo', download.dir = download.dir, download.only = TRUE, verbose = FALSE)
-install.bioinfo('github_demo', local.source = download.dir)
+install.bioinfo('github_demo', local.source = download.dir)}, error = function(e) {
+  message("Please check the SSL or connection with GitHub")
+})
 
 download.dir <- sprintf('%s/demo_local', tempdir())
 install.bioinfo('demo_2', download.dir = download.dir, download.only = TRUE, verbose = FALSE)
 install.bioinfo('demo_2', download.dir = download.dir, local.source = sprintf('%s/GRCh37_MT_ensGene.txt.gz', download.dir), decompress = TRUE)
 
 ## ------------------------------------------------------------------------
-download.dir <- sprintf('%s/craw_all_versions', tempdir())
-craw.all.versions('demo', download.dir = download.dir)
+download.dir <- sprintf('%s/crawl.all.versions', tempdir())
+crawl.all.versions('demo', download.dir = download.dir)
 
 ## ------------------------------------------------------------------------
 # Get all meta source files
@@ -65,7 +78,10 @@ meta_files
 
 # Get all of meta informaton in BioInstaller
 meta <- get.meta()
-meta
+names(meta)
+meta[1:4]
+meta$db$cfg_meta
+meta$db$item$atcircdb
 
 # Examples of get.meta
 db_cfg_meta <- get.meta(value = "cfg_meta", config = 'db')
@@ -87,8 +103,10 @@ db_meta_file
 # get all database name
 library(stringr)
 x <- install.bioinfo(show.all.names = T)
-x <- x[str_detect(x, "^db_")]
-x
+x <- x[str_detect(x, "^db_|reffa|bundle")]
+suppressWarnings(
+  DT::datatable(matrix(x, ncol=3), caption = sprintf("Database supported by BioInstaller (n=%s)", length(x)))
+)
 
 # all databases config 
 db_cfg_meta <- get.meta(config = 'db', value = 'cfg_meta', 
@@ -99,6 +117,7 @@ avaliable_cfg <- db_cfg_meta$avaliable_cfg
 avaliable_cfg
 sprintf("%s/%s", cfg_dir, avaliable_cfg)
 
+## ------------------------------------------------------------------------
 # ANNOVAR
 download.dir <- sprintf('%s/db_annovar', tempdir())
 config.toml <- system.file("extdata", "config/db/db_annovar.toml", 
@@ -113,3 +132,6 @@ config.toml <- system.file("extdata", "config/db/db_main.toml",
 install.bioinfo('db_diseaseenhancer', download.dir = download.dir, 
   nongithub.cfg = config.toml)
 
+## ----echo=FALSE----------------------------------------------------------
+sessionInfo()
+
